//=========================================================================
// MSP430 Design Challenge 2012 Force B
// File:			applications.c
// Description: 	Bluetooth Project: Application Subroutines
// Members:			Timothy Reyes, Dorothy Wong, Polina Vorozheykina
// Last Change:		07/24/2012
//=========================================================================

#include "msp430g2553.h"
#include "host.h"
#include "applications.h"
//=========================================================================
// Piano Notes
//=========================================================================

void cNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1900;
	TA0CCTL0 = CCIE;
}

void cSharpNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1805;
	TA0CCTL0 = CCIE;
}

void dNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1700;
	TA0CCTL0 = CCIE;
}

void dSharpNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1608;
	TA0CCTL0 = CCIE;
}

void eNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1500;
	TA0CCTL0 = CCIE;
}

void fNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1430;
	TA0CCTL0 = CCIE;
}

void fSharpNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1351;
	TA0CCTL0 = CCIE;
}

void gNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1280;
	TA0CCTL0 = CCIE;
}

void gSharpNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1205;
	TA0CCTL0 = CCIE;
}

void aNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1136;
	TA0CCTL0 = CCIE;
}

void aSharpNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1072;
	TA0CCTL0 = CCIE;
}

void bNote(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 1012;
	TA0CCTL0 = CCIE;
}

void cNoteOctave(void)
{
	P1DIR |= BIT5;
	P2DIR &= ~BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 956;
	TA0CCTL0 = CCIE;
}
//=========================================================================
// Strobe Light values
//=========================================================================

void strobe1(void)
{
	P1DIR &= ~BIT5;
	P2DIR |= BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 60000;
	TA0CCTL0 = CCIE;
}

void strobe2(void)
{
	P1DIR &= ~BIT5;
	P2DIR |= BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 50000;
	TA0CCTL0 = CCIE;
}

void strobe3(void)
{
	P1DIR &= ~BIT5;
	P2DIR |= BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 40000;
	TA0CCTL0 = CCIE;
}

void strobe4(void)
{
	P1DIR &= ~BIT5;
	P2DIR |= BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 30000;
	TA0CCTL0 = CCIE;
}

void strobe5(void)
{
	P1DIR &= ~BIT5;
	P2DIR |= BIT4;
	TA0CTL = TASSEL_2 + MC_1;
	TA0CCR0 = 20000;
	TA0CCTL0 = CCIE;
}
//=========================================================================
// Configure Timer
//=========================================================================

void configTimer(void)
{
	TA0CTL = TASSEL_2 + MC_1;			// SMCLK, upmode
	TA0CCR0 = 1000;						// Interrupt every 500us
	TA0CCTL0 = CCIE;					// timer interrupt enable
}

//=========================================================================
// Configure ADC Module
//=========================================================================

void configADC(void)
{
	ADC10CTL0 = ADC10SHT_2 + ADC10ON + ADC10IE; // ADC10ON, interrupt enabled
	ADC10CTL1 = INCH_4;                       // input A4
	ADC10AE0 |= BIT4;                         // PA.4 ADC option select
}

//=========================================================================
// Sample the ADC
//=========================================================================

unsigned short sampleADC(void)
{
	unsigned short sample;

	ADC10CTL0 |= ENC + ADC10SC;             // Sampling and conversion start
	_delay_cycles(1000);
	sample = ADC10MEM;
	ADC10CTL0 &= ~(ENC + ADC10SC);          // Sampling and conversion stop
	return sample;
}

//=========================================================================
// Interrupt Service Routines
//=========================================================================
// Timer A0 interrupt service routine
#pragma vector=TIMER0_A0_VECTOR
__interrupt void Timer_A (void)
{
	P1OUT ^= BIT5;                  // Toggle P1.5 Piano
	P2OUT ^= BIT4;					// Toggle P2.4 Leds
}

// ADC10 interrupt service routine
#pragma vector=ADC10_VECTOR
__interrupt void ADC10_ISR(void)
{

}
