//=========================================================================
// MSP430 Design Challenge 2012 Force B
// File:			host.c
// Description: 	Bluetooth Project: Host Communications Subroutines
// Members:			Timothy Reyes, Dorothy Wong, Polina Vorozheykina
// Last Change:		07/24/2012
//=========================================================================

#include "msp430g2553.h"
#include "host.h"
#include "applications.h"

//=========================================================================
// Global variables
//=========================================================================

bool rxDone;
bool txDone;
bool sleep;
unsigned char rxData;
unsigned int wdtCounter;
//=========================================================================
// UART Module Configuration
//=========================================================================

void configUART(void)
{
	P1SEL = BIT1 + BIT2;                     // P1.1 = RXD, P1.2=TXD
	P1SEL2 = BIT1 + BIT2;
	UCA0CTL1 |= UCSSEL_2;                     // SMCLK

	UCA0BR0 = 8;                              // 1MHz 115200
	UCA0BR1 = 0;                              // 1MHz 115200
	UCA0MCTL = UCBRS2 + UCBRS0;               // Modulation UCBRSx = 5

	UCA0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**
	IE2 |= UCA0RXIE;                          // Enable USCI_A0 RX interrupt
}

//=========================================================================
// Input/Output Configuration
//=========================================================================
void configIO(void)
{
	P1DIR |= BIT0 + BIT5 + BIT6 + BIT7;			// P1.0, 1.5, 1.6, 1.7 as outputs
	P1OUT &= ~(BIT0 + BIT5 + BIT6 + BIT7);
	P2DIR |= BIT4 + BIT5;						// P2.4 and 2.5 as outputs
	P2OUT &= ~(BIT4 + BIT5);
}

//=========================================================================
// Receive Input
//=========================================================================

unsigned char receiveInput(void)
{
	rxDone = false;
	while(!rxDone)
	{
		// Exit loop when rxData has been received
	}

	return rxData;		// set pointer to RXdata
}


//=========================================================================
// Send Output
//=========================================================================

void sendOutput(unsigned char txData)
{
	while (!(IFG2 & UCA0TXIFG));		// wait for TX register to be empty
	{
		UCA0TXBUF  = txData;			// send txData
	}
}

//=========================================================================
// UART RX Interrupt Service Routine
//=========================================================================

#pragma vector=USCIAB0RX_VECTOR
__interrupt void USCI0RX_ISR(void)
{
	rxData = UCA0RXBUF;
	rxDone = true;
	wdtCounter = 0; 					// reset watchdog timer counter
	if (sleep == true){
		_BIC_SR(LPM3_EXIT);				// wake up from low power mode
		P1OUT |= BIT0;					// visual indicator that device is active
		sleep = false;
	}
}

// Watchdog timer interrupt routine
#pragma vector = WDT_VECTOR
__interrupt void watchdog_timer(void)
{
	if(wdtCounter == 249){
		sleep = true;
		wdtCounter = 0;
		P1OUT |= BIT6;					// lock door : door motor P1.6
		P2OUT &= ~BIT5;					// turn off lights
		P1OUT &= ~BIT0;					// Visual indicator that device is in sleep mode
		_BIS_SR(LPM3_bits + GIE); 		// Enter LPM3 w/interrupt
	}
	else {
		wdtCounter++;
	}
}
