//=========================================================================
// MSP430 Design Challenge 2012
// File:			main.c
// Description: 	Bluetooth Project: Main Interface
// Members:			Timothy Reyes, Dorothy Wong, Polina Vorozheykina
// Last Change:		07/24/2012
//=========================================================================

#include "msp430g2553.h"
#include "host.h"
#include "applications.h"

//=========================================================================
// Global variables
//=========================================================================

unsigned char command;			// Command input from host
bool piano = true;
bool strobe = true;
bool door = false;
unsigned int door_val = 0;
extern unsigned int wdtCounter;
//=========================================================================
// Main subroutine
//=========================================================================

void main(void)
{
	WDTCTL = WDT_MDLY_32; 		// Set Watchdog Timer interval to ~32ms
	IE1 |= WDTIE;				// Enable WDT interrupt

	BCSCTL1 = CALBC1_1MHZ;  	// Set DCO = 1MHz
	DCOCTL = CALDCO_1MHZ;

	configIO();					// Configure input and output ports
	configUART();				// Configure USCI A0 UART module
	configADC();				// Configure ADC module
	_EINT();					// status register general enable interrupts
	P1OUT |= BIT0;				// Visual indicator that device is active

	while(1)
	{
		if (door == true){					// Check for door open or closed
			door_val = sampleADC();
				if (door_val <= 0x15){
					sendOutput(0x08);  		// door open
					P2OUT |= BIT4;
				}

				else{
					sendOutput(0x07); 		// door closed
					P2OUT &= ~BIT4;
				}
		}
//=======================================================================//
// 							OPcode Handler								 //
//=======================================================================//
// This handler is divided into three parts corresponding to the the 	 //
// three different demo modes.

		command = receiveInput();			// Ping user input and store in command
		switch(command)	{

			case 0x21:						// check if in range (for GUI)
				sendOutput(0x22);
			break;

//=======================================================================//
//							Home Security module						 //
//=======================================================================//
			case 0x00:							// launch home security tab
				TA0CCTL0 &= ~CCIE;				// turn off timer
				piano = false;					// disable piano
				strobe = false;					// disable strobing lights
				door = true;					// enable door
				P2OUT &= ~(BIT5 + BIT4);		// turn off leds
				P1OUT &= ~BIT6;
				if ((P2IN & 0x01) == 0x01){ 	// test door lock: tilt P2.0, door motor P1.6
					sendOutput(0x01);  			// locked
					P1OUT |= BIT6;
				}
				else{
					sendOutput(0x02); 			// unlocked
					P1OUT &= ~BIT6;
				}
			break;

			case 0x03:							// lock door : door motor P1.6
				P1OUT |= BIT6;
			break;

			case 0x04: 							// unlock door: door motor P1.6
				P1OUT &= ~BIT6;
			break;

			case 0x09: 							// turn on lights
				P2OUT |= BIT5;
			break;

			case 0x0A: 							// turn off lights
				P2OUT &= ~BIT5;
			break;

//=======================================================================//
//							Entertainment module						 //
//=======================================================================//
			case 0x20:   					// switch over to entertainment mode
				piano = true;				// enable piano
				strobe = true;				// enable strobing light
				door = false;				// disable door
				P2OUT &= ~(BIT4 + BIT5);	// turn off leds
				P1OUT &= ~BIT6;
			break;


			case 0x0B: 						// music on
				P2OUT |= BIT5;
			break;

			case 0x0C:						// music off
				P2OUT &= ~BIT5;
			break;

			case 0x0D: 						// disco on
				P1OUT |= BIT6;
			break;

			case 0x0E: 						// disco off
				P1OUT &= ~BIT6;
			break;

			case 0x30:  					// strobe lights off
				TA0CCTL0 &= ~CCIE;
				P2OUT &= ~BIT4;
			break;

			case 0x31: 	 					// strobe lights 1
				if (strobe == true)
				strobe1();
			break;

			case 0x32:  					// strobe lights 2
				if (strobe == true)
				strobe2();
			break;

			case 0x33:  					// strobe lights 3
				if (strobe == true)
				strobe3();
			break;

			case 0x34:  					// strobe lights 4
				if (strobe == true)
				strobe4();
			break;

			case 0x35:  					// strobe lights 5
				if (strobe == true)
				strobe5();
			break;

//=======================================================================//
// 							Piano Module								 //
//=======================================================================//
			case 0x40:						// enter piano module
				door = false;				// disable door
				strobe = false;				// disable strobe lights
				piano = true;				// enable piano
			break;

			case 'z':						// turn off piano
				TA0CCTL0 &= ~CCIE;
				P1OUT &= ~BIT5;
			break;

			case ('c'):
				if (piano == true)
					cNote();
			break;

			case 'f':
				if (piano == true)
					cSharpNote();
			break;

			case 'v':
				if (piano == true)
					dNote();
			break;

			case 'g':
				if (piano == true)
					dSharpNote();
			break;

			case 'b':
				if (piano == true)
					eNote();
			break;

			case 'n':
				if (piano == true)
					fNote();
			break;

			case 'j':
				if (piano == true)
					fSharpNote();
			break;

			case 'm':
				if (piano == true)
					gNote();
			break;

			case 'k':
				if (piano == true)
					gSharpNote();
			break;

			case ',':
				if (piano == true)
					aNote();
			break;

			case 'l':
				if (piano == true)
					aSharpNote();
			break;

			case '.':
				if (piano == true)
					bNote();
			break;

			case '/':
				if (piano == true)
					cNoteOctave();
			break;

			default:
			break;
		} 	// end case
	}	// end while
}	// end main
